pub struct TaskHandle { /* private fields */ }Expand description
A task-level view of a process, allowing only to poll or block for completion and to request the task to abort, rather than a stream of results.
Implementations