pub struct CallbackForwarder(/* private fields */);Expand description
Forwards run_graph requests; used to route these from a worker back to the
server (ancestor) which issued the run_function request (to that worker).
Implementations
Sourceimpl CallbackForwarder
impl CallbackForwarder
Sourcepub async fn new_connect(
uri: &Uri,
interceptor: ClientInterceptor,
) -> Result<Self>
pub async fn new_connect( uri: &Uri, interceptor: ClientInterceptor, ) -> Result<Self>
Connects to a remote Tierkreis server in order to forward callbacks onto it
Sourcepub async fn signature(
&self,
location: Location,
) -> Result<ListFunctionsResponse>
pub async fn signature( &self, location: Location, ) -> Result<ListFunctionsResponse>
Gets the signature (list of known functions + namespaces) of the server
Sourcepub fn as_runtime_worker(&self) -> &dyn RuntimeWorker
pub fn as_runtime_worker(&self) -> &dyn RuntimeWorker
Allows running graphs (/typechecking) by forwarding requests