pub struct EscapeHatch { /* private fields */ }Expand description
Used for forwarding “escape hatch” calls (a run_function sent from a child runtime
back to an ancestor).
Implementations
Sourceimpl EscapeHatch
impl EscapeHatch
Sourcepub fn this_runtime(target: Callback) -> Self
pub fn this_runtime(target: Callback) -> Self
An instance whereby run_functions execute on this runtime,
given a Callback telling child workers how to connect to this runtime.
Sourcepub fn new(parent: Option<FunctionForwarder>, this_runtime: Callback) -> Self
pub fn new(parent: Option<FunctionForwarder>, this_runtime: Callback) -> Self
Creates a new instance from a Callback to this runtime and optionally a parent.
If parent is non-null, then this_runtime should identify parent
in the servers EscapeHatch-forwarding map.
Sourcepub fn spawn_escape(&self, function: FunctionName) -> Option<RuntimeOperation>
pub fn spawn_escape(&self, function: FunctionName) -> Option<RuntimeOperation>
Cross-fingers that this runs a function. Deliberately no way to specify a location.