pub struct ExternalWorker { /* private fields */ }Expand description
Connection to an external worker (perhaps a Tierkreis server),
that can execute run_function for some defined+reported set of functions.
Implementations
Sourceimpl ExternalWorker
impl ExternalWorker
Sourcepub async fn new_spawn(
command: impl AsRef<OsStr>,
interceptor: ClientInterceptor,
) -> Result<Self>
pub async fn new_spawn( command: impl AsRef<OsStr>, interceptor: ClientInterceptor, ) -> Result<Self>
Spawn a process that runs the specified command, which must print out the socket address for a GRPC server as the first line of stdout. (We expect the command to start a new gRPC server in its own process.)
The socket address could be a hostname + port, or path to a UNIX filesystem socket.
new_spawn then connects to the worker’s gRPC server and requests its signature.
Sourcepub async fn new_connect(
uri: &Uri,
interceptor: ClientInterceptor,
) -> Result<Self>
pub async fn new_connect( uri: &Uri, interceptor: ClientInterceptor, ) -> Result<Self>
Connects to an already-running external process given its Uri