pub struct FunctionForwarder(/* private fields */);Expand description
A link in a forwarding chain - forwards run_function calls to a destination,
passing a Location which uniquely identifies the chain and the next link therein
(typically by the location being unique to each source/caller).
Implementations
Sourceimpl FunctionForwarder
impl FunctionForwarder
Sourcepub async fn new(
uri: &Uri,
interceptor: ClientInterceptor,
loc: Location,
) -> Result<Self>
pub async fn new( uri: &Uri, interceptor: ClientInterceptor, loc: Location, ) -> Result<Self>
Creates a new instance that forwards requests to a Uri, identifying itself with a Location
Sourcepub async fn fwd_run_function(
&self,
function: FunctionName,
inputs: HashMap<Label, Value>,
loc: Location,
callback: Callback,
node_trace: Option<NodeTrace>,
) -> Result<HashMap<Label, Value>>
pub async fn fwd_run_function( &self, function: FunctionName, inputs: HashMap<Label, Value>, loc: Location, callback: Callback, node_trace: Option<NodeTrace>, ) -> Result<HashMap<Label, Value>>
Forwards a call to run a function up the chain.
loc specifies the Location relative to the root of the forwarding chain.